@@ -22,10 +22,7 @@ use IO::File;
 my $logger = get_logger("Backend::Dpkg::Autopkgtest");
 my $user_logger = get_logger('User');
 
-sub read {
-    my $self = shift;
-    my %args = @_;
-
+sub read ($self, %args) { ## no critic (ProhibitBuiltinHomonyms)
     # args is:
     # object     => $obj,         # Config::Model::Node object
     # root       => './my_test',  # fake root directory, userd for tests
@@ -72,12 +69,10 @@ sub parse_control_file ($self, $control_file, $node, $check) {
             }
         }
     }
+    return;
 }
 
-sub write {
-    my $self = shift;
-    my %args = @_;
-
+sub write ($self, %args) { ## no critic (ProhibitBuiltinHomonyms)
     # args is:
     # object     => $obj,         # Config::Model::Node object
     # root       => './my_test',  # fake root directory, userd for tests
@@ -101,6 +96,8 @@ sub write_control_file ($self, $node, $control_file) {
     my $res = $self->write_dpkg_file(\@sections,", " ) ;
 
     $control_file->spew_utf8($res);
+
+    return;
 }
 
 1;
@@ -124,7 +121,9 @@ All C<Autopkgtest> files keyword are read in a case-insensitive manner.
 
 =head1 CONSTRUCTOR
 
-=head2 new ( node => $node_obj, name => 'Dpkg::Autopkgtest' ) ;
+=head2 new
+
+Parameters: C<< node => $node_obj, name => 'Dpkg::Autopkgtest' >>
 
 Inherited from L<Config::Model::Backend::Any>. The constructor will be
 called by L<Config::Model::AutoRead>.
@@ -133,7 +132,7 @@ called by L<Config::Model::AutoRead>.
 
 Read data from Autopkgtest files.
 
-When a file is read,  C<read()> returns 1.
+When a file is read, C<read()> returns 1.
 
 =head2 write
 
