@@ -341,7 +341,7 @@ sub dep_parser {
 # autoread started -> read all fileds -> read dependency -> check_dep ...
 
 around check_value => sub($orig, $self, @args) {
-    my %args = @_ > 1 ? @args : (value => $args[0]) ;
+    my %args = @args > 1 ? @args : (value => $args[0]) ;
 
     $args{fix} //= 0;
 	# when fixing, $orig->() may modify $args{value} before calling back
@@ -685,15 +685,17 @@ sub has_older_version_than {
     return (0,@list) ;
 }
 
-#
-# New subroutine "check_essential_package" extracted - Thu Aug 30 14:14:32 2012.
-#
 sub check_or_fix_essential_package {
     my ( $self, $apply_fix, $dep_info, $msgs ) = @_;
     my $pkg = $dep_info->{name};
     my ($oper, $vers) = @{ $dep_info->{dep} || []};
     $logger->debug("called with '", scalar $self->struct_to_dep($dep_info), "' and fix $apply_fix") if $logger->is_debug;
 
+    if (not defined $pkg) {
+        # pkg may be cleaned up during fix
+        return;
+    }
+
     # Remove unversioned dependency on essential package (Debian bug 684208)
     # see /usr/share/doc/libapt-pkg-perl/examples/apt-cache
 
