@@ -292,7 +292,7 @@ in ‘/usr/share/common-licenses/GPL-1’.",
                 qr/The Artistic License 2.0/,
                 {mode => 'custom', value => undef},
             ],
-            'Files:"3rdparty/libuv/samples/*" License short_name' => "BSD-3-clause and/or Expat",
+            'Files:"3rdparty/libuv/samples/socks5-proxy/*" License short_name' => "BSD-3-clause or Expat",
         },
         wr_check => {
             qq!Files:"3rdparty/dyncall/*" License full_license! => undef,
@@ -308,6 +308,17 @@ in ‘/usr/share/common-licenses/GPL-1’.",
         },
     },
 
+    {
+        # upgrade old moarvm copyright with recent output
+        name => 'moarvm-upgrade',
+        update => { in => path('t/scanner/examples/moarvm-upgrade.in'), quiet => 1 },
+        check => {
+            # check that old copyright entry of dir was cleaned up.
+            'Files:"*" Copyright' => "2012-2015, Jonathan Worthington and others.\n2012-2015, Jonathan Worthington"
+        },
+    },
+
+
     { # Debian bug  #797321
         name => 'warn-MIT',
         log4perl_load_warnings => [[ User => (warn => qr/many versions of the MIT license/) x 2 ]],
