@@ -1,13 +1,12 @@
-use Data::Dumper;
-use IO::File;
-use File::HomeDir ;
+use strict;
+use warnings;
 
-$conf_file_name = "some-patch";
+my $conf_file_name = "some-patch";
 
-$conf_dir       = 'debian/patches';
-$model_to_test  = "Dpkg::Patch";
+my $conf_dir       = 'debian/patches';
+my $model_to_test  = "Dpkg::Patch";
 
-@tests = (
+my @tests = (
     {
         name => 'libperl5i' ,
         backend_arg => $conf_file_name,
@@ -24,10 +23,8 @@ $model_to_test  = "Dpkg::Patch";
         load =>'Bug-Debian:.push(" http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=768073")',
         apply_fix => 1 ,
         check => {
-            'Synopsis' => qr/test TODO/,
-            'Subject' => qr/utf8/,
-            'Subject' => qr/879/,
-            'Subject' => qr/2012/,
+            'Subject' => qr/Make one test TODO/,
+            'Description' => [ qr/utf8::all/, qr/From 879/, qr/2012/ ],
             'Bug:0' => 'https://github.com/schwern/perl5i/issues/218',
             'Bug:1' => 'https://github.com/schwern/perl5i/issues/219',
             'Origin' => 'https://github.com/doherty/perl5i',
@@ -40,7 +37,7 @@ $model_to_test  = "Dpkg::Patch";
         name => 'moarvm' ,
         backend_arg => $conf_file_name,
         check => {
-            'Synopsis' => qr/Configure.pl/,
+            'Subject' => qr/Configure.pl/,
         },
         # check that subject stays first field
         file_contents_like => {
@@ -50,11 +47,12 @@ $model_to_test  = "Dpkg::Patch";
     {
         name => 'by-git',
         backend_arg => $conf_file_name,
-        dump_warnings => [ qr/Empty/ ],
         check => {
+            Synopsis => "Some patch", # set by apply_fix
             Description => qr/enhance/,
             diff => qr/@@ -7,7/
         },
+        apply_fix => 1,
         # check that description is first field
         file_contents_like => {
             "$conf_dir/$conf_file_name" => [ qr/^Description/ ] ,
@@ -70,8 +68,46 @@ $model_to_test  = "Dpkg::Patch";
         check => {
             Synopsis => 'Some patch',
         }
-    }
+    },
+    {
+        name => 'multi-line-subject',
+        backend_arg => $conf_file_name,
+        check => {
+            # the 2 lines of the Subject are glued together
+            Subject => 'pretend this is a long subject that got wrapped by gbp-pq',
+        }
+    },
+    {
+        name => 'subject-and-description',
+        backend_arg => $conf_file_name,
+        check => {
+            # the 2 lines of the Subject are glued together
+            Subject => 'Ensure the date is represented in UTC when generating PDF files.',
+            Description => qr/^Use SOURCE_DATE_EPOCH directly/,
+        }
+    },
+    {
+        name => 'subject-and-unstructured-description',
+        backend_arg => $conf_file_name,
+        check => {
+            # the 2 lines of the Subject are glued together
+            Subject => 'Ensure the date is represented in UTC when generating PDF files.',
+            Description => qr/^Use SOURCE_DATE_EPOCH directly/,
+        }
+    },
+    {
+        name => 'from-dep-3',
+        backend_arg => $conf_file_name,
+        check => {
+            # the 2 lines of the Subject are glued together
+            Subject => 'Fix regex problems with some multi-bytes characters',
+            Description => qr!^\* posix/bug-regex17.c!,
+        }
+    },
 );
 
-
-1;
+return {
+    conf_file_name => $conf_file_name,
+    conf_dir => $conf_dir,
+    tests => \@tests,
+};
