@@ -179,8 +179,7 @@ my @tests = (
             'copyright Files:pan/general/sorted-vector.h Copyright'
             => '2002, Martin Holzherr (holzherr@infobrain.com).',
             'copyright Files:pan/general/sorted-vector.h License short_name' => 'public-domain',
-            # entry "uulib/fptools.c\n uulib/fptools.h"is packed by update
-            qq'copyright Files:"*" Copyright' => '1994-2001, Frank Pilhofer.',
+            'copyright Files:"*" Copyright' => '2002-2007, Charles Kerr <charles@rebelbase.com>',
             'copyright Files:pan/gui/xface.c Copyright' => qr/James/,
         },
         wr_check => {
@@ -205,13 +204,13 @@ my @tests = (
             'copyright Files:pan/general/sorted-vector.h Copyright'
             => '2002, Martin Holzherr (holzherr@infobrain.com).',
             'copyright Files:pan/general/sorted-vector.h License short_name' => 'public-domain',
-            qq'copyright Files:"*" Copyright' => '1994-2001, Frank Pilhofer.',
+            'copyright Files:"*" Copyright' => '2002-2007, Charles Kerr <charles@rebelbase.com>',
         },
         has_key => {
             'copyright Files' => ['*'],
         },
         has_not_key => {
-            'copyright Files' => ['pan/data/*','uulib/*'],
+            'copyright Files' => ['pan/data/*'],
         },
         wr_check => {
             "copyright License:GPL-2 text" => {value => undef, mode => 'custom'},
@@ -255,9 +254,8 @@ my @tests = (
             quiet => 1,
             # fill.copyright.blanks tests #863052. Unfortunately, the
             # only symptom is a warning showing up during upgrade,
-            # hence this update_warnings which works only from
-            # Config::Model::Tester 2.061 (ignored otherwise)
-            update_warnings => []
+            # hence this log4perl_update_warnings
+            log4perl_update_warnings => []
         },
         file_contents_like => {
             'debian/copyright' => [
@@ -267,7 +265,7 @@ my @tests = (
         file_check_sub => tweak(qw/rules log/),
         # check that some entries were fixed by update
         check => {
-            'copyright Files:"share/vendor/*" Copyright' => '2010-2012, VMware, Inc.',
+            'copyright Files:"share/vendor/ruby/gems/rbvmomi/*" Copyright' => '2010-2012, VMware, Inc.',
             'copyright Files:"src/sunstone/public/css/novnc-custom.css" Copyright' => qr/Mannehed/,
             'copyright Files:"src/cloud/ec2/lib/net_ssh_replacement.rb" Copyright' => qr/Jamis/,
             'copyright Files:"share/pkgs/openSUSE/systemd/onedsetup" Copyright' => '2015, Marcel Mézigue',
@@ -384,11 +382,14 @@ my @tests = (
     {
         name => 'raku-uri',
         update => { in => path('t/scanner/examples/raku-uri.in') , quiet => 1 },
-        check => {
-            # README was wrong and is updated accordin to fill.copyright.blanks.yml
-            'copyright Files:"README.md" License short_name' => 'Artistic-2.0',
-            'copyright Files:"README.md" License full_license' => undef,
-        }
+        has_not_key => [
+            # README was wrong and is updated according to
+            # fill.copyright.blanks.yml which makes its license
+            # identical to main license, and its' copyright is
+            # "contained" in main copyright. So README.md is removed
+            # from the list of files.
+            'copyright Files' => 'README.md',
+        ],
     },
 );
 
